"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MAINNET = exports.TESTNET = void 0;
const axios_1 = __importDefault(require("axios"));
const log4js_1 = __importDefault(require("log4js"));
exports.TESTNET = 'testnet';
exports.MAINNET = 'mainnet';
/**
 * @memberof module:overledger-provider
 */
const log = log4js_1.default.getLogger('Provider');
log.level = 'info';
class Provider {
    /**
     * @param {ProviderOptions} ProviderOptions Overledger network provider options
     */
    constructor(options = {}) {
        this.options = options;
        this.network = this.options.network || exports.TESTNET;
    }
    /**
     * Creating a request, making this as flexible as possible with the possible values in the headers being passed in the method signature
     * @param path
     * @param accessToken
     * @param contentType
     * @param acceptString
     */
    createRequest(accessToken, contentType, acceptString) {
        let overledgerUri;
        if (this.network === exports.TESTNET) {
            overledgerUri = 'https://api.sandbox.overledger.io/v2';
        }
        else if (this.network === exports.MAINNET) {
            overledgerUri = 'https://api.overledger.io/v2';
        }
        else {
            overledgerUri = this.network;
        }
        const baseUrl = overledgerUri;
        const headersString = accessToken ? { Authorization: `Bearer ${accessToken}`, 'Content-type': contentType || 'application/json',
            Accept: acceptString || 'application/json' } : { 'Content-type': contentType || 'application/json', Accept: acceptString || 'application/json' };
        return axios_1.default.create({
            baseURL: baseUrl,
            timeout: this.options.timeout || 5000,
            headers: headersString,
        });
    }
}
exports.default = Provider;
//# sourceMappingURL=Provider.js.map